@@ -3,6 +3,9 @@ from zipfile import ZipFile
 from time import sleep
 import sys
 import os
+import io
+from typing import List
+
 from ..utils import get_file,get_vpk
 from ..config import systems
 from nonebot.log import logger
@@ -38,8 +41,12 @@ def open_packet(name:str,down_file:Path):
     if systems == 'win':
         if name.endswith('.zip'):
             mes = 'zip文件已下载,正在解压'
-            with ZipFile(down_file, 'r') as z:
-                z.extractall(down_path)
+            try:
+                with support_gbk(ZipFile(down_file, 'r')) as z:
+                    z.extractall(down_path)
+            except UnicodeEncodeError:
+                with ZipFile(down_file, 'r') as z:
+                    z.extractall(down_path)                
             os.remove(down_file)
         elif name.endswith('.7z'):
             mes ='7z文件已下载,正在解压'
@@ -75,7 +82,7 @@ def open_packet(name:str,down_file:Path):
             mes ='vpk文件已下载'        
     return mes
 
-def support_gbk(zip_file):
+def support_gbk(zip_file:ZipFile):
     '''
     压缩包中文恢复
     '''
@@ -88,14 +95,28 @@ def support_gbk(zip_file):
                 info.filename = real_name
                 del name_to_info[name]
                 name_to_info[real_name] = info
-    elif type(zip_file) == RarFile:
-        rar_file = zip_file
-        name_to_info = {info.filename: info for info in rar_file.infolist()}
-        for name, info in name_to_info.copy().items():
-            real_name = name.encode(sys.getfilesystemencoding(), errors='ignore').decode('gbk')
-            if real_name != name:
-                info.filename = real_name
-                del name_to_info[name]
-                name_to_info[real_name] = info
-                zip_file = rar_file
-    return zip_file
\ No newline at end of file
+    return zip_file
+
+
+
+
+async def all_zip_to_one(data_list:List[bytes]):
+    """多压缩包文件合并"""
+    file_list = []
+    for data in data_list:
+        # 将每个bytes对象解压缩成文件对象
+        # 将文件对象存储在一个列表中
+        file_list.append(io.BytesIO(data))
+
+    # 创建一个新的BytesIO对象
+    data_file = io.BytesIO()
+
+    # 使用zipfile将列表中的文件对象添加到zipfile中
+    with ZipFile(data_file, mode='w') as zf:
+        for i, file in enumerate(file_list):
+            # 将文件名设置为"file{i}.zip"，i为文件在列表中的索引
+            filename = f"file{i}.zip"
+            zf.writestr(filename, file.getvalue())
+
+    # 获取zipfile的bytes对象
+    return data_file.getvalue()
